@@ -76,11 +76,11 @@ def _plot_bucket_thumbnails(bucket_stats: List[Dict[str, Any]], viz_data: Dict)
     
     # Calculate grid layout for subplots
     n_buckets = len(sorted_buckets)
-    cols = min(3, n_buckets)
+    cols = min(4, n_buckets)
     rows = int(np.ceil(n_buckets / cols))
     
     # Create figure
-    fig, axes = plt.subplots(rows, cols, figsize=(cols * 6, rows * 6))
+    fig, axes = plt.subplots(rows, cols, figsize=(cols * 5, rows * 5))
     if n_buckets == 1:
         axes = [axes]
     elif rows == 1:
@@ -150,14 +150,8 @@ def _plot_bucket_thumbnails(bucket_stats: List[Dict[str, Any]], viz_data: Dict)
         grid_img = create_bucket_grid(bucket_images)
         ax.imshow(grid_img)
         
-        # Set title with bucket info
-        bucket_size = bucket_data['original_size']
-        kept = bucket_data['kept']
-        excluded = bucket_data['excluded']
-        kept_pct = (kept / bucket_size * 100) if bucket_size > 0 else 0
-        
-        ax.set_title(f"Bucket {bucket_idx + 1}\n{bucket_size} images, {kept_pct:.0f}% kept", 
-                    fontsize=12, pad=10)
+        # Set title with just bucket number
+        ax.set_title(f"Bucket {bucket_idx + 1}", fontsize=14, pad=10)
         ax.axis('off')
     
     # Hide unused subplots
